pyxmpp.jabberd.componentstream

Package pyxmpp :: Package jabberd :: Module componentstream |
[hide private]

# Module componentstream

source code

Component (jabber:component:accept) stream handling.

Normative reference:
  - JEP 114

Classes | [hide private]
| ComponentStream Handles jabberd component (jabber:component:accept) connection stream.

Variables | [hide private]
| __revision__ = ``'``$Id: componentstream.py 703 2010-04-03 17:45:4``...``
| __package__ = ``'``pyxmpp.jabberd``'``

Imports: hashlib, logging, Stream, stanza_factory, HostMismatch, common_doc, common_root, to_utf8, StreamError, FatalStreamError, ComponentStreamError, FatalComponentStreamError

Variables Details | [hide private]

  ### __revision__ Value:
      '$Id: componentstream.py 703 2010-04-03 17:45:43Z jajcus $'